@@ -3,5 +3,9 @@ pref("general.autoScroll",                 false);
 pref("general.useragent.locale",           "chrome://global/locale/intl.properties");
 pref("mail.shell.checkDefaultClient",      false);
 pref("intl.locale.requested",              "");
+/* Force hardware accelerated rendering due to USE=hwaccel */
+pref("layers.acceleration.force-enabled",  true);
+pref("webgl.force-enabled",                true);
+pref("gfx.x11-egl.force-enabled",          false);
 pref("spellchecker.dictionary_path",       "/usr/share/myspell");
 sticky_pref("gfx.font_rendering.graphite.enabled", true);
